@@ -5,6 +5,7 @@ Pytbox 主命令行入口
 
 import click
 from .categraf import categraf_group
+from .commands.vm import vm_group
 
 
 @click.group()
@@ -16,6 +17,7 @@ def main():
 
 # 注册子命令组
 main.add_command(categraf_group, name='categraf')
+main.add_command(vm_group, name='vm')
 
 
 if __name__ == "__main__":
